@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import sys
 from dataclasses import dataclass
 
 from bleak import BleakError
@@ -39,13 +40,23 @@ def local_name_to_serial(serial: str) -> str:
     return f"{serial[0:2]}XXX{serial[2:]}"
 
 
-def is_disconnected_error(error: Exception) -> bool:
-    """Check if the error is a disconnected error."""
+def is_key_error(error: Exception) -> bool:
+    """Check if the error likely due to the wrong key."""
+    err_str = str(error)
     return bool(
+        isinstance(error, BleakError)
+        and ("Unlikely Error" in err_str or "error=133" in err_str)
+    )
+
+
+def is_disconnected_error(error: Exception) -> bool:
+    """Check if the error is a disconnected error."""
+    err_str = str(error)
+    return is_key_error(error) or bool(
         isinstance(error, BleakError)
         and (
-            "disconnect" in str(error)
-            or "Connection Rejected Due To Security Reasons" in str(error)
+            "disconnect" in err_str
+            or "Connection Rejected Due To Security Reasons" in err_str
         )
     )
 
@@ -81,3 +92,9 @@ def unique_id_from_local_name_address(local_name: str, address: str) -> str:
 def local_name_is_unique(local_name: str | None) -> bool:
     """Check if the local name is unique."""
     return bool(local_name and len(local_name) == UNIQUE_LOCAL_NAME_LEN)
+
+
+if sys.version_info[:2] < (3, 11):
+    from async_timeout import timeout as asyncio_timeout  # noqa: F401
+else:
+    from asyncio import timeout as asyncio_timeout  # noqa: F401
